@@ -3,7 +3,7 @@ use warnings;
 no warnings 'uninitialized';
 
 package Form::Diva;
-$Form::Diva::VERSION = '0.19';
+$Form::Diva::VERSION = '1.00';
 # use Data::Printer;
 
 # ABSTRACT: Generate HTML5 form label and input fields
@@ -17,6 +17,8 @@ use Storable 2.51 qw(dclone);
 my %id_uq = ();
 sub _clear_id_uq { %id_uq = () }
 
+# our $id_base = 'formdiva_';
+
 # True if all fields are used no more than once, if not it dies.
 # Form::Diva->{FormHash} stores all the fields a duplicated fieldname
 # would replace the previous value.
@@ -361,9 +363,14 @@ sub hidden {
     return $output;
 }
 
+
+    # my $data      = _checkdatadbic( shift @_ );
+    # my $overide   = shift @_;
+    # my @generated = ();
+
 sub datavalues {
     my $self      = shift;
-    my $data      = shift;
+    my $data      = _checkdatadbic( shift @_ );
     my $skipempty = 0;
     my $moredata  = 0;
     for (@_) {
@@ -414,7 +421,7 @@ Form::Diva - Generate HTML5 form label and input fields
 
 =head1 VERSION
 
-version 0.19
+version 1.00
 
 =head1 AUTHOR
 
